import { ServerConfig } from "@thekla/config";
import WebDriver, { Client } from 'webdriver';
import { Browser, BrowserScreenshotData, CreateClient, ScreenshotOptions } from "../interface/Browser";
import { BrowserWindow, WindowManager } from "../interface/BrowserWindow";
import { ClientCtrls } from "../interface/ClientCtrls";
import { TkSession } from "../interface/TkSession";
import { FrameElementFinder, WebElementFinder, WebElementListFinder } from "../interface/WebElements";
import { Point } from "../lib/element/ElementLocation";
import { By } from "../lib/element/Locator";
export declare class ClientWdio implements Browser, ClientCtrls<Client>, WindowManager {
    private getClnt;
    private _selConfig;
    private _capabilities;
    private browserName;
    private static logger;
    private logger;
    private clientCreated;
    private _window;
    private static clientMap;
    private static attachedClientMap;
    private constructor();
    private resetAnnotator;
    get window(): BrowserWindow;
    get capabilities(): {
        [key: string]: any;
    };
    windowManagedBy(window: BrowserWindow): void;
    get serverConfig(): ServerConfig;
    pointerButtonDown: (button: number) => (client: WebDriver.Client) => Promise<WebDriver.Client>;
    pointerButtonUp: (button: number) => (client: WebDriver.Client) => Promise<WebDriver.Client>;
    movePointerTo: (point: Point) => (client: WebDriver.Client) => Promise<WebDriver.Client>;
    releaseActions: () => (client: WebDriver.Client) => Promise<WebDriver.Client>;
    getFrameWorkClient: () => Promise<WebDriver.Client>;
    static create({ serverConfig, capabilities, clientName, sessionId }: CreateClient): ClientWdio;
    static cleanup(clientsToClean?: Browser[], cleanAttachedSessions?: boolean): Promise<void[]>;
    /**
     * startedOn screenshots of all browser created with BrowserWdjs.startedOn
     *
     * @returns - and array of BrowserScreenshotData objects, the object contains the browser name and the screenshot data
     */
    static takeScreenshots(options?: ScreenshotOptions): Promise<BrowserScreenshotData[]>;
    /**
     * save all client screenshots to the given directory
     * prefix the given file name (baseFileName) with the client name
     * @param filepath - the directory where the files shall be saved
     * @param baseFileName - the filename which will be prefixed by the client name
     *
     * @returns - array of the screenshots file names
     */
    static saveScreenshots(filepath: string, baseFileName: string): Promise<string[]>;
    /**
     * return all names of newly created sessions
     *
     * @returns - Array of client names
     */
    static get availableNewClients(): string[];
    /**
     * return all names of attached sessions
     *
     * @returns - Array of client names
     */
    static get availableAttachedClients(): string[];
    /**
     * return the client by the given name
     * @param clientName -  the name of the client
     *
     * @returns  - the client for the given name
     *
     * @throws - an Error in case no client instance was found for the given client name
     */
    static getClientByName(clientName: string): Browser;
    element(locator: By): WebElementFinder;
    all(locator: By): WebElementListFinder;
    frame(locator: By): FrameElementFinder;
    get(url: string): Promise<void>;
    getWindowHandles(): Promise<string[]>;
    createWindow(): Promise<string>;
    createTab(): Promise<string>;
    closeWindow(): Promise<void>;
    switchToWindow(handle: string): Promise<void>;
    switchToWindowMatchingTheTitle(title: string): Promise<void>;
    getCurrentUrl(): Promise<string>;
    getTitle(): Promise<string>;
    executeScript(func: Function, ...funcArgs: any[]): Promise<{}>;
    quit(): Promise<void>;
    /**
     * save the browser screenshot to file
     * @param filepath - absolute or relative path to file
     * @param filename - filename
     *
     * @returns Promise with path to saved file
     */
    saveScreenshot(filepath: string, filename: string): Promise<string>;
    scrollTo({ x, y }: {
        x: number;
        y: number;
    }): Promise<void>;
    takeScreenshot(options?: ScreenshotOptions): Promise<BrowserScreenshotData>;
    wait: (condition: import("../lib/Condition").Condition, timeout?: number, waitMessage?: string) => Promise<string>;
    getSession(): Promise<TkSession>;
    uploadFile(filePath: string): Promise<string>;
}
//# sourceMappingURL=ClientWdio.d.ts.map